summaryrefslogtreecommitdiffstats
path: root/konversation/src/ignore_preferences.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/ignore_preferences.cpp')
-rw-r--r--konversation/src/ignore_preferences.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/konversation/src/ignore_preferences.cpp b/konversation/src/ignore_preferences.cpp
index 825cfb7..26a5a0a 100644
--- a/konversation/src/ignore_preferences.cpp
+++ b/konversation/src/ignore_preferences.cpp
@@ -17,35 +17,35 @@
#include <klocale.h>
#include <klistview.h>
-#include <qlistview.h>
-#include <qlineedit.h>
-#include <qheader.h>
+#include <tqlistview.h>
+#include <tqlineedit.h>
+#include <tqheader.h>
#include <kapplication.h>
#include <kconfig.h>
#include <kdebug.h>
#include <kpushbutton.h>
-#include <qcheckbox.h>
+#include <tqcheckbox.h>
-Ignore_Config::Ignore_Config( QWidget* parent, const char* name, WFlags fl )
+Ignore_Config::Ignore_Config( TQWidget* parent, const char* name, WFlags fl )
: Ignore_ConfigUI( parent, name, fl )
{
- connect(newButton,SIGNAL(clicked()),
- this,SLOT(newIgnore()));
- connect(removeButton,SIGNAL(clicked()),
- this,SLOT(removeIgnore()));
- connect(removeAllButton,SIGNAL(clicked()),
- this,SLOT(removeAllIgnore()));
- connect(ignoreListView,SIGNAL(selectionChanged(QListViewItem*)),
- this,SLOT(select(QListViewItem*)));
- connect(chkChannel, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
- connect(chkQuery, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
- connect(chkNotice, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
- connect(chkCTCP, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
- connect(chkDCC, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
- connect(txtPattern, SIGNAL(textChanged(const QString &)), this, SLOT(flagCheckboxChanged()));
-// connect(chkException, SIGNAL(clicked()), this, SLOT(flagCheckboxChanged()));
+ connect(newButton,TQT_SIGNAL(clicked()),
+ this,TQT_SLOT(newIgnore()));
+ connect(removeButton,TQT_SIGNAL(clicked()),
+ this,TQT_SLOT(removeIgnore()));
+ connect(removeAllButton,TQT_SIGNAL(clicked()),
+ this,TQT_SLOT(removeAllIgnore()));
+ connect(ignoreListView,TQT_SIGNAL(selectionChanged(TQListViewItem*)),
+ this,TQT_SLOT(select(TQListViewItem*)));
+ connect(chkChannel, TQT_SIGNAL(clicked()), this, TQT_SLOT(flagCheckboxChanged()));
+ connect(chkQuery, TQT_SIGNAL(clicked()), this, TQT_SLOT(flagCheckboxChanged()));
+ connect(chkNotice, TQT_SIGNAL(clicked()), this, TQT_SLOT(flagCheckboxChanged()));
+ connect(chkCTCP, TQT_SIGNAL(clicked()), this, TQT_SLOT(flagCheckboxChanged()));
+ connect(chkDCC, TQT_SIGNAL(clicked()), this, TQT_SLOT(flagCheckboxChanged()));
+ connect(txtPattern, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(flagCheckboxChanged()));
+// connect(chkException, TQT_SIGNAL(clicked()), this, TQT_SLOT(flagCheckboxChanged()));
loadSettings();
ignoreListView->header()->setMovingEnabled(false);
@@ -84,9 +84,9 @@ void Ignore_Config::removeIgnore()
emit modified();
}
-QPtrList<Ignore> Ignore_Config::getIgnoreList()
+TQPtrList<Ignore> Ignore_Config::getIgnoreList()
{
- QPtrList<Ignore> newList;
+ TQPtrList<Ignore> newList;
IgnoreListViewItem* item=static_cast<IgnoreListViewItem*>(ignoreListView->firstChild());
while(item)
@@ -99,10 +99,10 @@ QPtrList<Ignore> Ignore_Config::getIgnoreList()
return newList;
}
-// returns the currently visible ignore list as QStringList to make comparing easy
-QStringList Ignore_Config::currentIgnoreList()
+// returns the currently visible ignore list as TQStringList to make comparing easy
+TQStringList Ignore_Config::currentIgnoreList()
{
- QStringList newList;
+ TQStringList newList;
IgnoreListViewItem* item=static_cast<IgnoreListViewItem*>(ignoreListView->firstChild());
while(item)
@@ -137,7 +137,7 @@ void Ignore_Config::saveSettings()
void Ignore_Config::loadSettings()
{
- QPtrList<Ignore> ignoreList=Preferences::ignoreList();
+ TQPtrList<Ignore> ignoreList=Preferences::ignoreList();
// Insert Ignore items backwards to get them sorted properly
Ignore* item=ignoreList.last();
ignoreListView->clear();
@@ -167,7 +167,7 @@ void Ignore_Config::updateEnabledness()
}
-void Ignore_Config::select(QListViewItem* item)
+void Ignore_Config::select(TQListViewItem* item)
{
updateEnabledness();
// FIXME: Cast to IgnoreListViewItem, maybe derive from KListView some day